@@ -27,13 +27,18 @@
 
 int main (int argc, char *argv[])
 {
-	gnome_ppp.app = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
+	/*gnome_ppp.app = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
 			argc, argv, GNOME_PARAM_APP_DATADIR,
-			PACKAGE_DATA_DIR, NULL);
+			PACKAGE_DATA_DIR, NULL);*/
 	
+	#ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
+	#endif
+
+	gtk_set_locale ();
+	gtk_init (&argc, &argv);
 	
 	/* wvdial process */
 	wvdial.cmd[0] = NULL;
@@ -148,7 +153,26 @@ int main (int argc, char *argv[])
 	gnome_ppp.dock = FALSE;
 	/* icon factory */
 	gnome_ppp.icon_factory = NULL;
-		
+	/* conf path */
+	gnome_ppp.conf = NULL;
+
+	/* parse conf path */
+	gint i;
+
+	for (i = 0; i < argc; i++)
+	{
+		if (!strcmp (argv[i], "--conf")) {
+			
+			if (argv[i+1] != NULL) {
+				gnome_ppp.conf = g_strdup_printf (".%s", (argv[i+1]));
+				break;
+			}
+
+		} else {
+			gnome_ppp.conf = g_strdup (".wvdial.conf");
+		}
+	}
+
 	gchar *xml;
 	/* load glade xml */
 	xml = g_build_filename (PACKAGE_DATA_DIR, "glade", "gnome-ppp.glade", NULL);
@@ -158,7 +182,7 @@ int main (int argc, char *argv[])
 	/* app icon path variable */
 	gchar *icon;
 	icon = g_build_filename(PACKAGE_APPICON_DIR, "gnome-ppp.png", NULL);
-	
+
 	/* autoconnect callbacks */
 	glade_xml_signal_autoconnect (gnome_ppp.xml);
 	/* gnome ppp window */
@@ -238,7 +262,7 @@ int main (int argc, char *argv[])
 	gnome_ppp.phone.window = glade_xml_get_widget (gnome_ppp.xml, "phones");
 	gtk_window_set_icon_from_file (GTK_WINDOW (gnome_ppp.phone.window), icon, NULL);
 	gnome_ppp.phone.phone_nums = glade_xml_get_widget (gnome_ppp.xml, "phone_nums");
-	/* init strins list window */
+	/* init strings list window */
 	gnome_ppp.init_strs.window = glade_xml_get_widget (gnome_ppp.xml, "init_strings");
 	gtk_window_set_icon_from_file (GTK_WINDOW (gnome_ppp.phone.window), icon, NULL);
 	gnome_ppp.init_strs.init_strs = glade_xml_get_widget (gnome_ppp.xml, "init_strs");
