@@ -107,13 +107,13 @@ void init_notification (void)
 	gtk_menu_shell_append (GTK_MENU_SHELL (gnome_ppp.notification.menu), item);
 	gtk_widget_show (item);
 	
-	item = gtk_image_menu_item_new_with_label (_("About"));
+	/*item = gtk_image_menu_item_new_with_label (_("About"));
 	g_signal_connect (G_OBJECT (item ), "activate",
 			G_CALLBACK (on_notification_menu), "about");
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item),
 					gtk_image_new_from_stock (GNOME_STOCK_ABOUT, GTK_ICON_SIZE_MENU));
 	gtk_menu_shell_append (GTK_MENU_SHELL (gnome_ppp.notification.menu), item);
-	gtk_widget_show (item);
+	gtk_widget_show (item);*/
 }
 
 void update_notification (guint status)
@@ -180,7 +180,7 @@ void on_notification_menu (GtkWidget *widget, gpointer data)
 		on_conn_disconnect (NULL, NULL);
 	
 	if (g_strrstr (data, "about") != NULL) {
-		gchar *icon;
+		/*gchar *icon;
 
 		icon = g_build_filename (PACKAGE_APPICON_DIR, "gnome-ppp.png", NULL);
 
@@ -202,7 +202,7 @@ void on_notification_menu (GtkWidget *widget, gpointer data)
 		g_signal_connect (G_OBJECT (gnome_ppp.about), "destroy",
 				G_CALLBACK (gtk_widget_destroyed), &gnome_ppp.about);
 		
-		gtk_widget_show (gnome_ppp.about);
+		gtk_widget_show (gnome_ppp.about);*/
 	}
 	
 	if (g_strrstr (data, "log") != NULL)		
