@@ -120,7 +120,9 @@ void read_conf (void)
 	idle[0] = '\0';
 	
 	home = g_get_home_dir ();
-	wvconf = g_build_filename (home, ".wvdial.conf", NULL);
+	wvconf = g_build_filename (home, gnome_ppp.conf, NULL);
+
+	printf ("WVCONF: %s\n", wvconf);
 	
 	file = fopen (wvconf, "r");
 	
@@ -574,7 +576,7 @@ void populate_dns_list (const gchar *dns1, const gchar *dns2)
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (gnome_ppp.setup.list_dns), TRUE);
 }
 
-void write_conf()
+void write_conf(void)
 {
 	GtkTreeModel *model;
 	
@@ -692,7 +694,7 @@ void write_conf()
 	idle = gtk_spin_button_get_value (GTK_SPIN_BUTTON (gnome_ppp.setup.spin_idle));
 		
 	home = g_get_home_dir ();
-	wvconf = g_build_filename (home, ".wvdial.conf", NULL);
+	wvconf = g_build_filename (home, gnome_ppp.conf, NULL);
 
 	chmod (wvconf, S_IRUSR|S_IWUSR);
 	file = fopen (wvconf, "w");
@@ -916,7 +918,7 @@ void on_connect (GtkWidget *widget, gpointer data)
 	gtk_widget_show (gnome_ppp.connecting.window);
 	
 	home = g_get_home_dir ();
-	wvconf = g_build_filename (home, ".wvdial.conf", NULL);
+	wvconf = g_build_filename (home, gnome_ppp.conf, NULL);
 	
 	i = 0;
 	wvdial.cmd[i++] = "wvdial";
@@ -996,6 +998,9 @@ gboolean on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer data)
 	
 	if (gnome_ppp.init_strs.window != NULL)
 		gtk_widget_destroy (gnome_ppp.init_strs.window );
+
+	if (gnome_ppp.conf != NULL)
+		g_free (gnome_ppp.conf);
 	/* quit main gtk loop */
 	gtk_main_quit();
 	
